function three_body_problem(p1,p2)
if nargin == 0
    num = input('Choose case number: \n1)figure eight \n2)butterfly I \n3)moth I  \n4)ying-yang I \n5)butterfly II \n');
    switch num
        case 1
            p1 = .347111; p2 = .532728; T = 6.3244;
            name= 'Figure eight orbit';
            freegroup = 'ab';
            r = [-5,5,-5,5];
        case 2
            p1 = .30689; p2 = .12551; T = 6.2356;
            name = 'Butterfly I';
            freegroup = '(ab)^2(AB)^2';
            r = [-2,2,-.75,.75];
        case 3
            p1 = .46444; p2 = .39606; T = 14.8983;
            name = 'Moth I';
            freegroup = 'ba(BAB)ab(ABA)';
            r = [-3,3,-1.5,1.5];
        case 4
            p1 = .51394; p2 = .30474; T = 17.3284;
            name = 'Ying Yang I';
            freegroup = '(ab)^2(ABA)ba(BAB)';
            r = [-3,3,-2,2];
        case 5
            p1 = .39295; p2 = .09758; T = 7.0039;
            name = 'Butterfly II';
            freegroup = '(ab)^2(AB)^2';
            r = [-1.5,1.5,-.5,.5];
    end
else
    T = 10;
    name = 'Unknown orbit';
    freegroup = '';
end
%% obtain the position from the initial conditions
r1 = [-1;0]; r2 = [1;0]; r3 = [0;0];
v1 = [p1; p2]; v2 = [p1; p2]; v3 = [-2*p1; -2*p2];
Y = [r1; v1; r2; v2; r3; v3];

theta = linspace(0,2*pi,40); phi = zeros(1,40);
[a1,a2,a3] = sph2cart(phi,theta,1);
z1 = zeros(1,size(Y,1)); z2 = zeros(1,size(Y,1)); z3 = zeros(1,size(Y,1));
s1 = zeros(1,size(Y,1)); s2 = zeros(1,size(Y,1));

options = odeset('RelTol',1e-6,'AbsTol',1e-6);
[T1,Y] = ode45('kepler',[0 T],Y,options);
%% plot the data
x1 = min(min([Y(:,1),Y(:,5),Y(:,9)])); x2 = max(max([Y(:,1),Y(:,5),Y(:,9)]));
y1 = min(min([Y(:,2),Y(:,6),Y(:,10)])); y2 = max(max([Y(:,2),Y(:,6),Y(:,10)]));
t1 = zeros(1,size(Y,1)); t2 = zeros(1,size(Y,1)); t3 = zeros(1,size(Y,1));

for i = 1:size(Y,1)
    
    subplot(2,2,4);
    set(gca,'units','normalized','XTickLabel','','Yticklabel','');
    text(.1,.9,'Obrit Information:','linewidth',3);
    text(.1,.80,['Name:',name ]); text(.1,.7,'Free group elements:');
    text(.1,.6, freegroup); text(.1,.5, 'Initial velocities:');
    text(.1,.4,['p1 = ' ,num2str(p1),', p2 = ',num2str(p2)]);
    text(.1,.3,['Period = ',num2str(T)]);
    

    
[q1,q2,q3,z1(i),z2(i),z3(i),s1(i),s2(i)] = calc(Y(i,:));
    
    subplot(2,2,1);
    plot(Y(:,1),Y(:,2),'r-',Y(:,5),Y(:,6),'g-',Y(:,9),Y(:,10),'b-')
    axis([1.2*x1,1.2*x2,1.2*y1,1.2*y2])
    set(gca,'XTickLabel','','Yticklabel','');
    hold on

    plot([q1(1) q2(1)],[q1(2) q2(2)],'k',[q1(1) q3(1)],[q1(2) q3(2)],'k',[q2(1) q3(1)],[q2(2) q3(2)],'k');
    plot(q1(1), q1(2),'r.','Markersize',20 );
    plot(q2(1),q2(2), 'g.','Markersize',20 );
    plot(q3(1),q3(2), 'b.','Markersize',20 ); 
    message = ['Distances between bodies: r1=' ,num2str(norm(Y(i,1:2)-Y(i,5:6))), ', r2=', num2str(norm(Y(i,5:6)-Y(i,9:10))),', r3=',num2str(norm(Y(i,9:10)-Y(i,1:2)))];
    title(message);
    %pause(.01)
    
    
    
    
    subplot(2,2,2);
    hold on
    set(gca,'XTickLabel','','yTickLabel','','zTickLabel','')
    [y,x,z] = sphere(40);
    h = surfl(y,x, z);
    set(h, 'FaceAlpha', 0.5)
    colormap('pink');
    lightangle(100,190) 
    shading interp
    title(name);
   plot3(a1,a2,a3,'b-',[sind(45),-sind(45),0],[0,0,0],[-cosd(45),-cosd(45),1],'b.','markersize',15);
    plot3(z1(i),z2(i),z3(i),'o', 'MarkerFaceColor',[1 .6 0 ],'markersize',7);
    plot3(z1(1:i),z2(1:i),z3(1:i),'k-');
    plot3([0,z1(i)],[0,z2(i)],[1,z3(i)],'r-');
    view([0 -72]);
    
    
    
    
    subplot(2,2,3);
    hold on
    title('Stereographic Projection');
    set(gca,'XTickLabel','','yTickLabel','')
    plot(-1,0,'r.',1,0,'r.','markersize',5);   
    w = linspace(-3,3,20);
    plot(s1(1:i),s2(1:i),'k-');
    if nargin ==0 
        axis(r);
    end
    drawnow


    if i~=size(Y,1);
    clf;
    end
end
end
